theme_extensions_gen library

Functions

contextExtensionsGenerator(BuilderOptions options) → Builder
A Builder that reads .theme_templates.json metadata and generates an extension on BuildContext with getters for all template class names. For example, an annotation over AppThemeBottomBar -> getter appThemeBottomBar
themeExtensionsGenerator(dynamic _) → Builder
Provides a Builder that generates theme extensions from annotations.
themeExtensionsImplCollector(dynamic _) → Builder
A Builder that generates temporary .theme_impl.json metadata files used by the final combiner step. Does not require part directives.
themeExtensionsImplCombiner(BuilderOptions options) → Builder
A Builder that reads .theme_impl.json metadata and generates a Dart file with a merged list of ThemeExtension instances.
themeExtensionsTemplatesCollector(dynamic _) → Builder
A Builder that collects theme template class names and generates a file with ContextThemeExtensions. Temporary .theme_templates.json metadata is used for the final combiner step. Does not require part directives.